# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/polymer/app/search/v1/search.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2
from bilireq.grpc.protos.bilibili.pagination import pagination_pb2 as bilibili_dot_pagination_dot_pagination__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+bilibili/polymer/app/search/v1/search.proto\x12\x1e\x62ilibili.polymer.app.search.v1\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\x1a$bilibili/pagination/pagination.proto\"\x8c\x01\n\x04\x41rgs\x12\x0e\n\x06online\x18\x01 \x01(\x05\x12\r\n\x05rname\x18\x02 \x01(\t\x12\x0f\n\x07room_id\x18\x03 \x01(\x03\x12\r\n\x05tname\x18\x04 \x01(\t\x12\r\n\x05up_id\x18\x05 \x01(\x03\x12\x0f\n\x07up_name\x18\x06 \x01(\t\x12\x0b\n\x03rid\x18\x07 \x01(\x03\x12\x0b\n\x03tid\x18\x08 \x01(\x03\x12\x0b\n\x03\x61id\x18\t \x01(\x03\"\xbc\x01\n\x06\x41vatar\x12\r\n\x05\x63over\x18\x01 \x01(\t\x12\r\n\x05\x65vent\x18\x02 \x01(\t\x12\x10\n\x08\x65vent_v2\x18\x03 \x01(\t\x12\x0c\n\x04text\x18\x04 \x01(\t\x12\r\n\x05up_id\x18\x05 \x01(\x03\x12\x0b\n\x03uri\x18\x06 \x01(\t\x12\x14\n\x0c\x66\x61\x63\x65_nft_new\x18\x07 \x01(\x05\x12\x42\n\rnft_face_icon\x18\x08 \x01(\x0b\x32+.bilibili.polymer.app.search.v1.NftFaceIcon\"\xcf\x01\n\x06\x41vItem\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x13\n\x0b\x63time_label\x18\x04 \x01(\t\x12\x10\n\x08\x64uration\x18\x05 \x01(\t\x12\x0c\n\x04play\x18\x06 \x01(\x05\x12\x0f\n\x07\x64\x61nmaku\x18\x07 \x01(\x03\x12\r\n\x05\x63time\x18\x08 \x01(\x05\x12\x0c\n\x04goto\x18\t \x01(\t\x12\r\n\x05param\x18\n \x01(\t\x12\x10\n\x08position\x18\x0b \x01(\x05\x12\x16\n\x0e\x63time_label_v2\x18\x0c \x01(\t\"B\n\nBackground\x12\x0c\n\x04show\x18\x01 \x01(\x05\x12\x12\n\nbg_pic_url\x18\x02 \x01(\t\x12\x12\n\nfg_pic_url\x18\x03 \x01(\t\"\'\n\x05\x42\x61\x64ge\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x10\n\x08\x62g_cover\x18\x02 \x01(\t\"(\n\x06\x42\x61\x64ge2\x12\x10\n\x08\x62g_cover\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\"*\n\x0c\x42ottomButton\x12\x0c\n\x04\x64\x65sc\x18\x01 \x01(\t\x12\x0c\n\x04link\x18\x02 \x01(\t\"\xfa\x02\n\x0e\x42randADAccount\x12\r\n\x05param\x18\x01 \x01(\t\x12\x0c\n\x04goto\x18\x02 \x01(\t\x12\x0b\n\x03mid\x18\x03 \x01(\x03\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x05 \x01(\t\x12\x0c\n\x04sign\x18\x06 \x01(\t\x12:\n\x08relation\x18\x07 \x01(\x0b\x32(.bilibili.polymer.app.search.v1.Relation\x12\x0e\n\x06roomid\x18\x08 \x01(\x03\x12\x13\n\x0blive_status\x18\t \x01(\x03\x12\x11\n\tlive_link\x18\n \x01(\t\x12G\n\x0fofficial_verify\x18\x0b \x01(\x0b\x32..bilibili.polymer.app.search.v1.OfficialVerify\x12\x34\n\x03vip\x18\x0c \x01(\x0b\x32\'.bilibili.polymer.app.search.v1.VipInfo\x12\x0b\n\x03uri\x18\r \x01(\t\x12\x14\n\x0c\x66\x61\x63\x65_nft_new\x18\x0e \x01(\x05\"\xa0\x01\n\nBrandADArc\x12\r\n\x05param\x18\x01 \x01(\t\x12\x0c\n\x04goto\x18\x02 \x01(\t\x12\x0b\n\x03\x61id\x18\x03 \x01(\x03\x12\x0c\n\x04play\x18\x04 \x01(\x03\x12\r\n\x05reply\x18\x05 \x01(\x03\x12\x10\n\x08\x64uration\x18\x06 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x07 \x01(\t\x12\r\n\x05title\x18\x08 \x01(\t\x12\x0b\n\x03uri\x18\t \x01(\t\x12\r\n\x05\x63over\x18\n \x01(\t\"\xaf\x01\n\x06\x42utton\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\r\n\x05param\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\r\n\x05\x65vent\x18\x04 \x01(\t\x12\x10\n\x08selected\x18\x05 \x01(\x05\x12\x0c\n\x04type\x18\x06 \x01(\x05\x12\x10\n\x08\x65vent_v2\x18\x07 \x01(\t\x12:\n\x08relation\x18\x08 \x01(\x0b\x32(.bilibili.polymer.app.search.v1.Relation\"N\n\nButtonMeta\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x15\n\rbutton_status\x18\x03 \x01(\t\x12\r\n\x05toast\x18\x04 \x01(\t\"\x92\x01\n\x11\x43\x61rdBusinessBadge\x12;\n\tgoto_icon\x18\x01 \x01(\x0b\x32(.bilibili.polymer.app.search.v1.GotoIcon\x12@\n\x0b\x62\x61\x64ge_style\x18\x02 \x01(\x0b\x32+.bilibili.polymer.app.search.v1.ReasonStyle\")\n\x0c\x43hannelLabel\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\xd1\x01\n\x10\x43hannelMixedItem\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x18\n\x10\x63over_left_icon1\x18\x02 \x01(\x05\x12\x18\n\x10\x63over_left_text1\x18\x03 \x01(\t\x12\r\n\x05\x63over\x18\x04 \x01(\t\x12\x0c\n\x04goto\x18\x05 \x01(\t\x12\r\n\x05param\x18\x06 \x01(\t\x12\x0b\n\x03uri\x18\x07 \x01(\t\x12\r\n\x05title\x18\x08 \x01(\t\x12\x35\n\x05\x62\x61\x64ge\x18\t \x01(\x0b\x32&.bilibili.polymer.app.search.v1.Badge2\")\n\tCheckMore\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"5\n\x0f\x43loudGameParams\x12\x13\n\x0bsource_from\x18\x01 \x01(\x03\x12\r\n\x05scene\x18\x02 \x01(\t\"\xcb\x02\n\x13\x44\x65tailsRelationItem\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x17\n\x0f\x63over_left_text\x18\x03 \x01(\t\x12\x46\n\x11\x63over_badge_style\x18\x04 \x01(\x0b\x32+.bilibili.polymer.app.search.v1.ReasonStyle\x12\x12\n\nmodule_pos\x18\x05 \x01(\t\x12\x0c\n\x04goto\x18\x06 \x01(\t\x12\r\n\x05param\x18\x07 \x01(\t\x12\x0b\n\x03uri\x18\x08 \x01(\t\x12\x10\n\x08position\x18\t \x01(\x05\x12\x1a\n\x12\x63over_left_text_v2\x18\n \x01(\t\x12I\n\x14\x63over_badge_style_v2\x18\x0b \x01(\x0b\x32+.bilibili.polymer.app.search.v1.ReasonStyle\")\n\rDislikeReason\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\"I\n\rDisplayOption\x12\x17\n\x0fvideo_title_row\x18\x01 \x01(\x05\x12\x1f\n\x17search_page_visual_opti\x18\x02 \x01(\x05\"%\n\x07\x44yTopic\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\xec\x01\n\tEasterEgg\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nshow_count\x18\x02 \x01(\x05\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\x0b\n\x03url\x18\x04 \x01(\t\x12\x13\n\x0b\x63lose_count\x18\x05 \x01(\x05\x12\x19\n\x11mask_transparency\x18\x06 \x01(\x05\x12\x12\n\nmask_color\x18\x07 \x01(\t\x12\x10\n\x08pic_type\x18\x08 \x01(\x05\x12\x11\n\tshow_time\x18\t \x01(\x05\x12\x12\n\nsource_url\x18\n \x01(\t\x12\x12\n\nsource_md5\x18\x0b \x01(\t\x12\x13\n\x0bsource_size\x18\x0c \x01(\x05\"\x83\x01\n\x07\x45pisode\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\r\n\x05param\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\t\x12;\n\x06\x62\x61\x64ges\x18\x04 \x03(\x0b\x32+.bilibili.polymer.app.search.v1.ReasonStyle\x12\x10\n\x08position\x18\x05 \x01(\x05\"\xc2\x01\n\nEpisodeNew\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05param\x18\x03 \x01(\t\x12\x0e\n\x06is_new\x18\x04 \x01(\x05\x12;\n\x06\x62\x61\x64ges\x18\x05 \x03(\x0b\x32+.bilibili.polymer.app.search.v1.ReasonStyle\x12\x0c\n\x04type\x18\x06 \x01(\x05\x12\x10\n\x08position\x18\x07 \x01(\x05\x12\r\n\x05\x63over\x18\x08 \x01(\t\x12\r\n\x05label\x18\t \x01(\t\"&\n\tExtraLink\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\xa9\x01\n\x0c\x46ollowButton\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x46\n\x05texts\x18\x02 \x03(\x0b\x32\x37.bilibili.polymer.app.search.v1.FollowButton.TextsEntry\x12\x15\n\rstatus_report\x18\x03 \x01(\t\x1a,\n\nTextsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"`\n\x0e\x46ullTextResult\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x11\n\tshow_text\x18\x02 \x01(\t\x12\x1b\n\x13jump_start_progress\x18\x03 \x01(\x03\x12\x10\n\x08jump_uri\x18\x04 \x01(\t\"]\n\x08GotoIcon\x12\x10\n\x08icon_url\x18\x01 \x01(\t\x12\x16\n\x0eicon_night_url\x18\x02 \x01(\t\x12\x12\n\nicon_width\x18\x03 \x01(\x05\x12\x13\n\x0bicon_height\x18\x04 \x01(\x05\"i\n\x11InlineProgressBar\x12\x11\n\ticon_drag\x18\x01 \x01(\t\x12\x16\n\x0eicon_drag_hash\x18\x02 \x01(\t\x12\x11\n\ticon_stop\x18\x03 \x01(\t\x12\x16\n\x0eicon_stop_hash\x18\x04 \x01(\t\"\xa0\x01\n\x15InlineThreePointPanel\x12\x12\n\npanel_type\x18\x01 \x01(\x05\x12\x10\n\x08share_id\x18\x02 \x01(\t\x12\x14\n\x0cshare_origin\x18\x03 \x01(\t\x12K\n\x12\x66unctional_buttons\x18\x04 \x03(\x0b\x32/.bilibili.polymer.app.search.v1.ShareButtonItem\"\xe0\x13\n\x04Item\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\r\n\x05param\x18\x02 \x01(\t\x12\x0c\n\x04goto\x18\x03 \x01(\t\x12\x10\n\x08linktype\x18\x04 \x01(\t\x12\x10\n\x08position\x18\x05 \x01(\x05\x12\x0f\n\x07trackid\x18\x06 \x01(\t\x12\x44\n\x07special\x18\x07 \x01(\x0b\x32\x31.bilibili.polymer.app.search.v1.SearchSpecialCardH\x00\x12\x44\n\x07\x61rticle\x18\x08 \x01(\x0b\x32\x31.bilibili.polymer.app.search.v1.SearchArticleCardH\x00\x12\x42\n\x06\x62\x61nner\x18\t \x01(\x0b\x32\x30.bilibili.polymer.app.search.v1.SearchBannerCardH\x00\x12>\n\x04live\x18\n \x01(\x0b\x32..bilibili.polymer.app.search.v1.SearchLiveCardH\x00\x12>\n\x04game\x18\x0b \x01(\x0b\x32..bilibili.polymer.app.search.v1.SearchGameCardH\x00\x12\x46\n\x08purchase\x18\x0c \x01(\x0b\x32\x32.bilibili.polymer.app.search.v1.SearchPurchaseCardH\x00\x12Q\n\x0erecommend_word\x18\r \x01(\x0b\x32\x37.bilibili.polymer.app.search.v1.SearchRecommendWordCardH\x00\x12\x44\n\x07\x64ynamic\x18\x0e \x01(\x0b\x32\x31.bilibili.polymer.app.search.v1.SearchDynamicCardH\x00\x12X\n\x0fsuggest_keyword\x18\x0f \x01(\x0b\x32=.bilibili.polymer.app.search.v1.SearchNoResultSuggestWordCardH\x00\x12O\n\rspecial_guide\x18\x10 \x01(\x0b\x32\x36.bilibili.polymer.app.search.v1.SearchSpecialGuideCardH\x00\x12@\n\x05\x63omic\x18\x11 \x01(\x0b\x32/.bilibili.polymer.app.search.v1.SearchComicCardH\x00\x12K\n\x0b\x63hannel_new\x18\x12 \x01(\x0b\x32\x34.bilibili.polymer.app.search.v1.SearchNewChannelCardH\x00\x12\x41\n\x08ogv_card\x18\x13 \x01(\x0b\x32-.bilibili.polymer.app.search.v1.SearchOgvCardH\x00\x12P\n\x0f\x62\x61ngumi_relates\x18\x14 \x01(\x0b\x32\x35.bilibili.polymer.app.search.v1.SearchOgvRelationCardH\x00\x12K\n\tfind_more\x18\x15 \x01(\x0b\x32\x36.bilibili.polymer.app.search.v1.SearchOgvRecommendCardH\x00\x12\x41\n\x06\x65sport\x18\x16 \x01(\x0b\x32/.bilibili.polymer.app.search.v1.SearchSportCardH\x00\x12I\n\nauthor_new\x18\x17 \x01(\x0b\x32\x33.bilibili.polymer.app.search.v1.SearchAuthorNewCardH\x00\x12>\n\x04tips\x18\x18 \x01(\x0b\x32..bilibili.polymer.app.search.v1.SearchTipsCardH\x00\x12:\n\x02\x63m\x18\x19 \x01(\x0b\x32,.bilibili.polymer.app.search.v1.SearchAdCardH\x00\x12\x45\n\npedia_card\x18\x1a \x01(\x0b\x32/.bilibili.polymer.app.search.v1.SearchPediaCardH\x00\x12I\n\nugc_inline\x18\x1b \x01(\x0b\x32\x33.bilibili.polymer.app.search.v1.SearchUgcInlineCardH\x00\x12K\n\x0blive_inline\x18\x1c \x01(\x0b\x32\x34.bilibili.polymer.app.search.v1.SearchLiveInlineCardH\x00\x12\x45\n\x08top_game\x18\x1d \x01(\x0b\x32\x31.bilibili.polymer.app.search.v1.SearchTopGameCardH\x00\x12G\n\x06sports\x18\x1e \x01(\x0b\x32\x35.bilibili.polymer.app.search.v1.SearchOlympicGameCardH\x00\x12R\n\x11pedia_card_inline\x18\x1f \x01(\x0b\x32\x35.bilibili.polymer.app.search.v1.SearchOlympicWikiCardH\x00\x12P\n\x0erecommend_tips\x18  \x01(\x0b\x32\x36.bilibili.polymer.app.search.v1.SearchRecommendTipCardH\x00\x12O\n\x0f\x63ollection_card\x18! \x01(\x0b\x32\x34.bilibili.polymer.app.search.v1.SearchCollectionCardH\x00\x12K\n\x0bogv_channel\x18\" \x01(\x0b\x32\x34.bilibili.polymer.app.search.v1.SearchOgvChannelCardH\x00\x12I\n\nogv_inline\x18# \x01(\x0b\x32\x33.bilibili.polymer.app.search.v1.SearchOgvInlineCardH\x00\x12\x41\n\x06\x61uthor\x18$ \x01(\x0b\x32/.bilibili.polymer.app.search.v1.SearchUpperCardH\x00\x12=\n\x02\x61v\x18% \x01(\x0b\x32/.bilibili.polymer.app.search.v1.SearchVideoCardH\x00\x12\x44\n\x07\x62\x61ngumi\x18& \x01(\x0b\x32\x31.bilibili.polymer.app.search.v1.SearchBangumiCardH\x00\x12O\n\x0e\x65sports_inline\x18\' \x01(\x0b\x32\x35.bilibili.polymer.app.search.v1.SearchSportInlineCardH\x00\x42\x0b\n\tcard_item\"1\n\x0cLikeResource\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x14\n\x0c\x63ontent_hash\x18\x02 \x01(\t\"\xd2\x01\n\x11LiveBadgeResource\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x15\n\ranimation_url\x18\x02 \x01(\t\x12\x1a\n\x12\x61nimation_url_hash\x18\x03 \x01(\t\x12\x1e\n\x16\x62\x61\x63kground_color_light\x18\x04 \x01(\t\x12\x1e\n\x16\x62\x61\x63kground_color_night\x18\x05 \x01(\t\x12\x13\n\x0b\x61lpha_light\x18\x06 \x01(\x03\x12\x13\n\x0b\x61lpha_night\x18\x07 \x01(\x03\x12\x12\n\nfont_color\x18\x08 \x01(\t\"v\n\x04Mask\x12\x36\n\x06\x61vatar\x18\x01 \x01(\x0b\x32&.bilibili.polymer.app.search.v1.Avatar\x12\x36\n\x06\x62utton\x18\x02 \x01(\x0b\x32&.bilibili.polymer.app.search.v1.Button\"\xf3\x02\n\x0cMatchInfoObj\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12\x13\n\x0bmatch_stage\x18\x03 \x01(\t\x12\x38\n\x05team1\x18\x04 \x01(\x0b\x32).bilibili.polymer.app.search.v1.MatchTeam\x12\x38\n\x05team2\x18\x05 \x01(\x0b\x32).bilibili.polymer.app.search.v1.MatchTeam\x12>\n\x0bmatch_label\x18\x06 \x01(\x0b\x32).bilibili.polymer.app.search.v1.MatchItem\x12=\n\nmatch_time\x18\x07 \x01(\x0b\x32).bilibili.polymer.app.search.v1.MatchItem\x12?\n\x0cmatch_button\x18\x08 \x01(\x0b\x32).bilibili.polymer.app.search.v1.MatchItem\"\xac\x01\n\tMatchItem\x12\r\n\x05state\x18\x01 \x01(\x05\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x12\n\ntext_color\x18\x03 \x01(\t\x12\x18\n\x10text_color_night\x18\x04 \x01(\t\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12\x11\n\tlive_link\x18\x06 \x01(\t\x12\x34\n\x05texts\x18\x07 \x01(\x0b\x32%.bilibili.polymer.app.search.v1.Texts\"D\n\tMatchTeam\x12\n\n\x02id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\r\n\x05score\x18\x04 \x01(\x05\"?\n\x03Nav\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05total\x18\x02 \x01(\x05\x12\r\n\x05pages\x18\x03 \x01(\x05\x12\x0c\n\x04type\x18\x04 \x01(\x05\"\xf9\x01\n\nNavigation\x12\n\n\x02id\x18\x01 \x01(\x03\x12<\n\x08\x63hildren\x18\x02 \x03(\x0b\x32*.bilibili.polymer.app.search.v1.Navigation\x12\x43\n\x0finline_children\x18\x03 \x03(\x0b\x32*.bilibili.polymer.app.search.v1.Navigation\x12\r\n\x05title\x18\x04 \x01(\t\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12@\n\x06\x62utton\x18\x06 \x01(\x0b\x32\x30.bilibili.polymer.app.search.v1.NavigationButton\";\n\x10NavigationButton\x12\x0c\n\x04type\x18\x01 \x01(\x03\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"E\n\x0bNftFaceIcon\x12\x13\n\x0bregion_type\x18\x01 \x01(\x05\x12\x0c\n\x04icon\x18\x02 \x01(\t\x12\x13\n\x0bshow_status\x18\x03 \x01(\x05\"\xd5\x01\n\x06Notice\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x11\n\tnotice_id\x18\x02 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\x12\x13\n\x0bnotice_type\x18\x05 \x01(\x03\x12\x0c\n\x04icon\x18\x06 \x01(\t\x12\x12\n\nicon_night\x18\x07 \x01(\t\x12\x12\n\ntext_color\x18\x08 \x01(\t\x12\x18\n\x10text_color_night\x18\t \x01(\t\x12\x10\n\x08\x62g_color\x18\n \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x0b \x01(\t\",\n\x0eOfficialVerify\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\"X\n\tOgvCardUI\x12\x18\n\x10\x62\x61\x63kground_image\x18\x01 \x01(\t\x12\x1b\n\x13gaussian_blur_value\x18\x02 \x01(\t\x12\x14\n\x0cmodule_color\x18\x03 \x01(\t\"=\n\x0bOgvClipInfo\x12\x17\n\x0fplay_start_time\x18\x01 \x01(\x03\x12\x15\n\rplay_end_time\x18\x02 \x01(\x03\"K\n\x10OgvRecommendWord\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04goto\x18\x02 \x01(\t\x12\r\n\x05param\x18\x03 \x01(\t\x12\x0b\n\x03uri\x18\x04 \x01(\t\"{\n\nPediaCover\x12\x12\n\ncover_type\x18\x01 \x01(\x03\x12\x15\n\rcover_sun_url\x18\x02 \x01(\t\x12\x17\n\x0f\x63over_night_url\x18\x03 \x01(\t\x12\x13\n\x0b\x63over_width\x18\x04 \x01(\x05\x12\x14\n\x0c\x63over_height\x18\x05 \x01(\x05\"\xd2\x02\n\nPlayerArgs\x12\x0f\n\x07is_live\x18\x01 \x01(\x05\x12\x0b\n\x03\x61id\x18\x02 \x01(\x03\x12\x0b\n\x03\x63id\x18\x03 \x01(\x03\x12\x10\n\x08sub_type\x18\x04 \x01(\x05\x12\x0f\n\x07room_id\x18\x05 \x01(\x03\x12\r\n\x05\x65p_id\x18\x07 \x01(\x03\x12\x12\n\nis_preview\x18\x08 \x01(\x05\x12\x0c\n\x04type\x18\t \x01(\t\x12\x10\n\x08\x64uration\x18\n \x01(\x05\x12\x11\n\tseason_id\x18\x0b \x01(\x03\x12%\n\x1dreport_required_play_duration\x18\x0c \x01(\x05\x12\x1c\n\x14report_required_time\x18\r \x01(\x05\x12\x13\n\x0bmanual_play\x18\x0e \x01(\x05\x12\x18\n\x10hide_play_button\x18\x0f \x01(\x08\x12\x14\n\x0c\x63ontent_mode\x18\x10 \x01(\x05\x12\x16\n\x0ereport_history\x18\x11 \x01(\x05\"+\n\x0cPlayerWidget\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\"\xed\x01\n\x08RankInfo\x12\x1d\n\x15search_night_icon_url\x18\x01 \x01(\t\x12\x1b\n\x13search_day_icon_url\x18\x02 \x01(\t\x12\x1e\n\x16search_bkg_night_color\x18\x03 \x01(\t\x12\x1c\n\x14search_bkg_day_color\x18\x04 \x01(\t\x12\x1f\n\x17search_font_night_color\x18\x05 \x01(\t\x12\x1d\n\x15search_font_day_color\x18\x06 \x01(\t\x12\x14\n\x0crank_content\x18\x07 \x01(\t\x12\x11\n\trank_link\x18\x08 \x01(\t\"\x1d\n\nRcmdReason\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\"\xb7\x01\n\x0bReasonStyle\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\ntext_color\x18\x02 \x01(\t\x12\x18\n\x10text_color_night\x18\x03 \x01(\t\x12\x10\n\x08\x62g_color\x18\x04 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x05 \x01(\t\x12\x14\n\x0c\x62order_color\x18\x06 \x01(\t\x12\x1a\n\x12\x62order_color_night\x18\x07 \x01(\t\x12\x10\n\x08\x62g_style\x18\x08 \x01(\x05\"P\n\rRecommendWord\x12\r\n\x05param\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x13\n\x0b\x66rom_source\x18\x04 \x01(\t\"\x1a\n\x08Relation\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x85\x01\n\x11RightTopLiveBadge\x12\x13\n\x0blive_status\x18\x01 \x01(\x05\x12\x42\n\x07in_live\x18\x02 \x01(\x0b\x32\x31.bilibili.polymer.app.search.v1.LiveBadgeResource\x12\x17\n\x0flive_stats_desc\x18\x03 \x01(\t\" \n\x0cSearchAdCard\x12\x10\n\x08json_str\x18\x01 \x01(\t\"\xba\x02\n\x10SearchAllRequest\x12\x0f\n\x07keyword\x18\x01 \x01(\t\x12\r\n\x05order\x18\x02 \x01(\x05\x12\x10\n\x08tid_list\x18\x03 \x01(\t\x12\x15\n\rduration_list\x18\x04 \x01(\t\x12\x12\n\nextra_word\x18\x05 \x01(\t\x12\x13\n\x0b\x66rom_source\x18\x06 \x01(\t\x12\x14\n\x0cis_org_query\x18\x07 \x01(\x05\x12\x12\n\nlocal_time\x18\x08 \x01(\x05\x12\x10\n\x08\x61\x64_extra\x18\t \x01(\t\x12\x33\n\npagination\x18\n \x01(\x0b\x32\x1f.bilibili.pagination.Pagination\x12\x43\n\x0bplayer_args\x18\x0b \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"\xe0\x04\n\x11SearchAllResponse\x12\x0f\n\x07keyword\x18\x01 \x01(\t\x12\x0f\n\x07trackid\x18\x02 \x01(\t\x12\x30\n\x03nav\x18\x03 \x03(\x0b\x32#.bilibili.polymer.app.search.v1.Nav\x12\x32\n\x04item\x18\x04 \x03(\x0b\x32$.bilibili.polymer.app.search.v1.Item\x12=\n\neaster_egg\x18\x05 \x01(\x0b\x32).bilibili.polymer.app.search.v1.EasterEgg\x12\x0f\n\x07\x65xp_str\x18\x06 \x01(\t\x12\x17\n\x0f\x65xtra_word_list\x18\x07 \x03(\t\x12\x16\n\x0eorg_extra_word\x18\x08 \x01(\t\x12\x17\n\x0fselect_bar_type\x18\t \x01(\x03\x12\x1a\n\x12new_search_exp_num\x18\n \x01(\x03\x12\x38\n\npagination\x18\x0b \x01(\x0b\x32$.bilibili.pagination.PaginationReply\x12I\n\x12\x61pp_display_option\x18\x0c \x01(\x0b\x32-.bilibili.polymer.app.search.v1.DisplayOption\x12U\n\nannotation\x18\r \x03(\x0b\x32\x41.bilibili.polymer.app.search.v1.SearchAllResponse.AnnotationEntry\x1a\x31\n\x0f\x41nnotationEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd8\x01\n\x11SearchArticleCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0c\n\x04play\x18\x03 \x01(\x05\x12\x0c\n\x04like\x18\x04 \x01(\x05\x12\r\n\x05reply\x18\x05 \x01(\x05\x12\x12\n\nimage_urls\x18\x06 \x03(\t\x12\x0e\n\x06\x61uthor\x18\x07 \x01(\t\x12\x13\n\x0btemplate_id\x18\x08 \x01(\x05\x12\n\n\x02id\x18\t \x01(\x03\x12\x0b\n\x03mid\x18\n \x01(\x03\x12\x0c\n\x04name\x18\x0b \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x0c \x01(\t\x12\x0c\n\x04view\x18\r \x01(\x05\"\x88\x08\n\x13SearchAuthorNewCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x11\n\tlive_face\x18\x03 \x01(\x05\x12\x10\n\x08live_uri\x18\x04 \x01(\t\x12\x11\n\tlive_link\x18\x05 \x01(\t\x12\x0c\n\x04\x66\x61ns\x18\x06 \x01(\x05\x12\r\n\x05level\x18\x07 \x01(\x05\x12\x0c\n\x04sign\x18\x08 \x01(\t\x12\r\n\x05is_up\x18\t \x01(\x08\x12\x10\n\x08\x61rchives\x18\n \x01(\x05\x12\x0b\n\x03mid\x18\x0b \x01(\x03\x12\x0e\n\x06roomid\x18\x0c \x01(\x03\x12:\n\x08relation\x18\r \x01(\x0b\x32(.bilibili.polymer.app.search.v1.Relation\x12G\n\x0fofficial_verify\x18\x0e \x01(\x0b\x32..bilibili.polymer.app.search.v1.OfficialVerify\x12\x14\n\x0c\x66\x61\x63\x65_nft_new\x18\x0f \x01(\x05\x12\x42\n\rnft_face_icon\x18\x10 \x01(\x0b\x32+.bilibili.polymer.app.search.v1.NftFaceIcon\x12\x18\n\x10is_senior_member\x18\x11 \x01(\x05\x12>\n\nbackground\x18\x12 \x01(\x0b\x32*.bilibili.polymer.app.search.v1.Background\x12\x10\n\x08\x61v_style\x18\x13 \x01(\x05\x12\x34\n\x05space\x18\x14 \x01(\x0b\x32%.bilibili.polymer.app.search.v1.Space\x12\x38\n\x08\x61v_items\x18\x15 \x03(\x0b\x32&.bilibili.polymer.app.search.v1.AvItem\x12\x36\n\x06notice\x18\x16 \x01(\x0b\x32&.bilibili.polymer.app.search.v1.Notice\x12?\n\x0bshare_plane\x18\x17 \x01(\x0b\x32*.bilibili.polymer.app.search.v1.SharePlane\x12\x13\n\x0binline_type\x18\x18 \x01(\t\x12\x45\n\x0binline_live\x18\x19 \x01(\x0b\x32\x30.bilibili.polymer.app.search.v1.SearchInlineData\x12\x16\n\x0eis_inline_live\x18\x1a \x01(\x05\x12?\n\x0bthree_point\x18\x1b \x03(\x0b\x32*.bilibili.polymer.app.search.v1.ThreePoint\x12\x13\n\x0blive_status\x18\x1c \x01(\x05\x12\x34\n\x03vip\x18\x1d \x01(\x0b\x32\'.bilibili.polymer.app.search.v1.VipInfo\"\xc6\x07\n\x11SearchBangumiCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x12\n\nmedia_type\x18\x03 \x01(\x05\x12\x12\n\nplay_state\x18\x04 \x01(\x05\x12\x0c\n\x04\x61rea\x18\x05 \x01(\t\x12\r\n\x05style\x18\x06 \x01(\t\x12\x0e\n\x06styles\x18\x07 \x01(\t\x12\n\n\x02\x63v\x18\x08 \x01(\t\x12\x0e\n\x06rating\x18\t \x01(\x01\x12\x0c\n\x04vote\x18\n \x01(\x05\x12\x0e\n\x06target\x18\x0b \x01(\t\x12\r\n\x05staff\x18\x0c \x01(\t\x12\x0e\n\x06prompt\x18\r \x01(\t\x12\r\n\x05ptime\x18\x0e \x01(\x03\x12\x18\n\x10season_type_name\x18\x0f \x01(\t\x12\x39\n\x08\x65pisodes\x18\x10 \x03(\x0b\x32\'.bilibili.polymer.app.search.v1.Episode\x12\x14\n\x0cis_selection\x18\x11 \x01(\x05\x12\x10\n\x08is_atten\x18\x12 \x01(\x05\x12\r\n\x05label\x18\x13 \x01(\t\x12\x11\n\tseason_id\x18\x14 \x01(\x03\x12\x10\n\x08out_name\x18\x15 \x01(\t\x12\x10\n\x08out_icon\x18\x16 \x01(\t\x12\x0f\n\x07out_url\x18\x17 \x01(\t\x12;\n\x06\x62\x61\x64ges\x18\x18 \x03(\x0b\x32+.bilibili.polymer.app.search.v1.ReasonStyle\x12\x0e\n\x06is_out\x18\x19 \x01(\x05\x12@\n\x0c\x65pisodes_new\x18\x1a \x03(\x0b\x32*.bilibili.polymer.app.search.v1.EpisodeNew\x12\x41\n\x0cwatch_button\x18\x1b \x01(\x0b\x32+.bilibili.polymer.app.search.v1.WatchButton\x12\x17\n\x0fselection_style\x18\x1c \x01(\t\x12=\n\ncheck_more\x18\x1d \x01(\x0b\x32).bilibili.polymer.app.search.v1.CheckMore\x12\x43\n\rfollow_button\x18\x1e \x01(\x0b\x32,.bilibili.polymer.app.search.v1.FollowButton\x12@\n\x0bstyle_label\x18\x1f \x01(\x0b\x32+.bilibili.polymer.app.search.v1.ReasonStyle\x12>\n\tbadges_v2\x18  \x03(\x0b\x32+.bilibili.polymer.app.search.v1.ReasonStyle\x12\x11\n\tstyles_v2\x18! \x01(\t\"0\n\x10SearchBannerCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\"\xc2\x06\n\x13SearchByTypeRequest\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0f\n\x07keyword\x18\x02 \x01(\t\x12W\n\rcategory_sort\x18\x03 \x01(\x0e\x32@.bilibili.polymer.app.search.v1.SearchByTypeRequest.CategorySort\x12\x13\n\x0b\x63\x61tegory_id\x18\x04 \x01(\x03\x12O\n\tuser_type\x18\x05 \x01(\x0e\x32<.bilibili.polymer.app.search.v1.SearchByTypeRequest.UserType\x12O\n\tuser_sort\x18\x06 \x01(\x0e\x32<.bilibili.polymer.app.search.v1.SearchByTypeRequest.UserSort\x12\x33\n\npagination\x18\x07 \x01(\x0b\x32\x1f.bilibili.pagination.Pagination\x12\x43\n\x0bplayer_args\x18\x08 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"\xa7\x01\n\x0c\x43\x61tegorySort\x12\x19\n\x15\x43\x41TEGORY_SORT_DEFAULT\x10\x00\x12\x1e\n\x1a\x43\x41TEGORY_SORT_PUBLISH_TIME\x10\x01\x12\x1d\n\x19\x43\x41TEGORY_SORT_CLICK_COUNT\x10\x02\x12\x1f\n\x1b\x43\x41TEGORY_SORT_COMMENT_COUNT\x10\x03\x12\x1c\n\x18\x43\x41TEGORY_SORT_LIKE_COUNT\x10\x04\"D\n\x08UserType\x12\x07\n\x03\x41LL\x10\x00\x12\x06\n\x02UP\x10\x01\x12\x0f\n\x0bNORMAL_USER\x10\x02\x12\x16\n\x12\x41UTHENTICATED_USER\x10\x03\"\x91\x01\n\x08UserSort\x12\x15\n\x11USER_SORT_DEFAULT\x10\x00\x12\x1a\n\x16USER_SORT_FANS_DESCEND\x10\x01\x12\x19\n\x15USER_SORT_FANS_ASCEND\x10\x02\x12\x1b\n\x17USER_SORT_LEVEL_DESCEND\x10\x03\x12\x1a\n\x16USER_SORT_LEVEL_ASCEND\x10\x04\"\xf1\x02\n\x14SearchByTypeResponse\x12\x0f\n\x07trackid\x18\x01 \x01(\t\x12\r\n\x05pages\x18\x02 \x01(\x05\x12\x0f\n\x07\x65xp_str\x18\x03 \x01(\t\x12\x0f\n\x07keyword\x18\x04 \x01(\t\x12\x1b\n\x13result_is_recommend\x18\x05 \x01(\x05\x12\x33\n\x05items\x18\x06 \x03(\x0b\x32$.bilibili.polymer.app.search.v1.Item\x12\x38\n\npagination\x18\x07 \x01(\x0b\x32$.bilibili.pagination.PaginationReply\x12X\n\nannotation\x18\x08 \x03(\x0b\x32\x44.bilibili.polymer.app.search.v1.SearchByTypeResponse.AnnotationEntry\x1a\x31\n\x0f\x41nnotationEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8e\x02\n\x14SearchCollectionCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x03 \x01(\t\x12\x38\n\x08\x61v_items\x18\x04 \x03(\x0b\x32&.bilibili.polymer.app.search.v1.AvItem\x12\x43\n\rbottom_button\x18\x05 \x01(\x0b\x32,.bilibili.polymer.app.search.v1.BottomButton\x12\x17\n\x0f\x63ollection_icon\x18\x06 \x01(\t\x12\x17\n\x0fshow_card_desc1\x18\x07 \x01(\t\x12\x17\n\x0fshow_card_desc2\x18\x08 \x01(\t\"n\n\x0fSearchComicCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05style\x18\x04 \x01(\t\x12\x11\n\tcomic_url\x18\x05 \x01(\t\x12\r\n\x05\x62\x61\x64ge\x18\x06 \x01(\t\"m\n\x0fSearchComicInfo\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\r\n\x05param\x18\x02 \x01(\t\x12>\n\x05\x63omic\x18\x03 \x01(\x0b\x32/.bilibili.polymer.app.search.v1.SearchComicCard\"%\n\x12SearchComicRequest\x12\x0f\n\x07id_list\x18\x01 \x01(\t\"U\n\x13SearchComicResponse\x12>\n\x05items\x18\x01 \x03(\x0b\x32/.bilibili.polymer.app.search.v1.SearchComicInfo\"\xfb\x01\n\x11SearchDynamicCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x13\n\x0b\x63over_count\x18\x03 \x01(\x05\x12\x0e\n\x06\x63overs\x18\x04 \x03(\t\x12\x34\n\x05upper\x18\x05 \x01(\x0b\x32%.bilibili.polymer.app.search.v1.Upper\x12\x32\n\x04stat\x18\x06 \x01(\x0b\x32$.bilibili.polymer.app.search.v1.Stat\x12\x39\n\x08\x64y_topic\x18\x07 \x03(\x0b\x32\'.bilibili.polymer.app.search.v1.DyTopic\"\x8c\x03\n\x0eSearchGameCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0f\n\x07reserve\x18\x03 \x01(\t\x12\x0e\n\x06rating\x18\x04 \x01(\x02\x12\x0c\n\x04tags\x18\x05 \x01(\t\x12\x13\n\x0bnotice_name\x18\x06 \x01(\t\x12\x16\n\x0enotice_content\x18\x07 \x01(\t\x12\x14\n\x0cgift_content\x18\x08 \x01(\t\x12\x10\n\x08gift_url\x18\t \x01(\t\x12\x16\n\x0ereserve_status\x18\n \x01(\x05\x12;\n\trank_info\x18\x0b \x01(\x0b\x32(.bilibili.polymer.app.search.v1.RankInfo\x12\x18\n\x10special_bg_color\x18\x0c \x01(\t\x12J\n\x11\x63loud_game_params\x18\r \x01(\x0b\x32/.bilibili.polymer.app.search.v1.CloudGameParams\x12\x1d\n\x15show_cloud_game_entry\x18\x0e \x01(\x08\"\xc4\x0c\n\x10SearchInlineData\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12?\n\x0bplayer_args\x18\x03 \x01(\x0b\x32*.bilibili.polymer.app.search.v1.PlayerArgs\x12\x10\n\x08\x63\x61n_play\x18\x04 \x01(\x05\x12\x32\n\x04\x61rgs\x18\x05 \x01(\x0b\x32$.bilibili.polymer.app.search.v1.Args\x12\x11\n\tcard_goto\x18\x06 \x01(\t\x12\x11\n\tcard_type\x18\x07 \x01(\t\x12\r\n\x05\x63over\x18\x08 \x01(\t\x12\x18\n\x10\x63over_left_icon1\x18\t \x01(\x05\x12\x18\n\x10\x63over_left_icon2\x18\n \x01(\x05\x12\x18\n\x10\x63over_left_text1\x18\x0b \x01(\t\x12\x18\n\x10\x63over_left_text2\x18\x0c \x01(\t\x12\x37\n\x07up_args\x18\r \x01(\x0b\x32&.bilibili.polymer.app.search.v1.UpArgs\x12\x11\n\textra_uri\x18\x0e \x01(\t\x12\x0e\n\x06is_fav\x18\x0f \x01(\x08\x12\x0f\n\x07is_coin\x18\x10 \x01(\x08\x12\x0c\n\x04goto\x18\x11 \x01(\t\x12\x34\n\x05share\x18\x12 \x01(\x0b\x32%.bilibili.polymer.app.search.v1.Share\x12@\n\x0bthree_point\x18\x13 \x01(\x0b\x32+.bilibili.polymer.app.search.v1.ThreePoint2\x12\x44\n\x0ethree_point_v2\x18\x14 \x03(\x0b\x32,.bilibili.polymer.app.search.v1.ThreePointV2\x12?\n\x0bshare_plane\x18\x15 \x01(\x0b\x32*.bilibili.polymer.app.search.v1.SharePlane\x12O\n\x10three_point_meta\x18\x16 \x01(\x0b\x32\x35.bilibili.polymer.app.search.v1.InlineThreePointPanel\x12\x36\n\x06\x61vatar\x18\x17 \x01(\x0b\x32&.bilibili.polymer.app.search.v1.Avatar\x12\x18\n\x10\x63over_right_text\x18\x18 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x19 \x01(\t\x12N\n\x13inline_progress_bar\x18\x1a \x01(\x0b\x32\x31.bilibili.polymer.app.search.v1.InlineProgressBar\x12I\n\x0blike_button\x18\x1b \x01(\x0b\x32\x34.bilibili.polymer.app.search.v1.SearchLikeButtonItem\x12\x15\n\rofficial_icon\x18\x1c \x01(\x05\x12\x18\n\x10official_icon_v2\x18\x1d \x01(\x05\x12\r\n\x05param\x18\x1e \x01(\t\x12\x45\n\x0etraffic_config\x18\x1f \x01(\x0b\x32-.bilibili.polymer.app.search.v1.TrafficConfig\x12\x10\n\x08is_atten\x18  \x01(\x08\x12;\n\tgoto_icon\x18! \x01(\x0b\x32(.bilibili.polymer.app.search.v1.GotoIcon\x12\x17\n\x0f\x64isable_danmaku\x18\" \x01(\x08\x12\x1b\n\x13hide_danmaku_switch\x18# \x01(\x08\x12@\n\x0b\x62\x61\x64ge_style\x18$ \x01(\x0b\x32+.bilibili.polymer.app.search.v1.ReasonStyle\x12\x43\n\rplayer_widget\x18% \x01(\x0b\x32,.bilibili.polymer.app.search.v1.PlayerWidget\x12\x46\n\x11\x63over_badge_style\x18& \x01(\x0b\x32+.bilibili.polymer.app.search.v1.ReasonStyle\x12O\n\x14right_top_live_badge\x18\' \x01(\x0b\x32\x31.bilibili.polymer.app.search.v1.RightTopLiveBadge\"\xfe\x02\n\x14SearchLikeButtonItem\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\r\n\x05\x63ount\x18\x02 \x01(\x03\x12\x10\n\x08selected\x18\x03 \x01(\x05\x12\x12\n\nshow_count\x18\x04 \x01(\x08\x12\x43\n\rlike_resource\x18\x05 \x01(\x0b\x32,.bilibili.polymer.app.search.v1.LikeResource\x12I\n\x13like_night_resource\x18\x06 \x01(\x0b\x32,.bilibili.polymer.app.search.v1.LikeResource\x12\x46\n\x10\x64islike_resource\x18\x07 \x01(\x0b\x32,.bilibili.polymer.app.search.v1.LikeResource\x12L\n\x16\x64islike_night_resource\x18\x08 \x01(\x0b\x32,.bilibili.polymer.app.search.v1.LikeResource\"\xc9\x02\n\x0eSearchLiveCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12?\n\x0brcmd_reason\x18\x03 \x01(\x0b\x32*.bilibili.polymer.app.search.v1.RcmdReason\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06online\x18\x05 \x01(\x05\x12\r\n\x05\x62\x61\x64ge\x18\x06 \x01(\t\x12\x11\n\tlive_link\x18\x07 \x01(\t\x12\x16\n\x0e\x63\x61rd_left_text\x18\x08 \x01(\t\x12\x16\n\x0e\x63\x61rd_left_icon\x18\t \x01(\x05\x12\x17\n\x0fshow_card_desc2\x18\n \x01(\t\x12O\n\x14right_top_live_badge\x18\x0b \x01(\x0b\x32\x31.bilibili.polymer.app.search.v1.RightTopLiveBadge\"\x8d\x02\n\x14SearchLiveInlineCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03mid\x18\x03 \x01(\x03\x12\x46\n\x11rcmd_reason_style\x18\x04 \x01(\x0b\x32+.bilibili.polymer.app.search.v1.ReasonStyle\x12\x0e\n\x06roomid\x18\x05 \x01(\x03\x12\x11\n\tlive_link\x18\x06 \x01(\t\x12J\n\x10live_room_inline\x18\x07 \x01(\x0b\x32\x30.bilibili.polymer.app.search.v1.SearchInlineData\x12\x13\n\x0binline_type\x18\x08 \x01(\t\"\xfb\x02\n\x14SearchNewChannelCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\x03\x12\x11\n\ttype_icon\x18\x04 \x01(\t\x12\x44\n\x0e\x63hannel_label1\x18\x05 \x01(\x0b\x32,.bilibili.polymer.app.search.v1.ChannelLabel\x12\x44\n\x0e\x63hannel_label2\x18\x06 \x01(\x0b\x32,.bilibili.polymer.app.search.v1.ChannelLabel\x12\x44\n\x0e\x63hannel_button\x18\x07 \x01(\x0b\x32,.bilibili.polymer.app.search.v1.ChannelLabel\x12\x13\n\x0b\x64\x65sign_type\x18\x08 \x01(\t\x12?\n\x05items\x18\t \x03(\x0b\x32\x30.bilibili.polymer.app.search.v1.ChannelMixedItem\"X\n\x1dSearchNoResultSuggestWordCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x19\n\x11sug_key_word_type\x18\x03 \x01(\x05\"\x94\x01\n\rSearchOgvCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\x12\n\nsub_title1\x18\x02 \x01(\t\x12\x12\n\nsub_title2\x18\x03 \x01(\t\x12\r\n\x05\x63over\x18\x04 \x01(\t\x12\x10\n\x08\x62g_cover\x18\x05 \x01(\t\x12\x18\n\x10special_bg_color\x18\x06 \x01(\t\x12\x11\n\tcover_uri\x18\x07 \x01(\t\"\xb6\x02\n\x14SearchOgvChannelCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x10\n\x08media_id\x18\x03 \x01(\x03\x12\x0e\n\x06styles\x18\x04 \x01(\t\x12\x0c\n\x04\x61rea\x18\x05 \x01(\t\x12\r\n\x05staff\x18\x06 \x01(\t\x12\r\n\x05\x62\x61\x64ge\x18\x07 \x01(\t\x12\x41\n\x0cwatch_button\x18\x08 \x01(\x0b\x32+.bilibili.polymer.app.search.v1.WatchButton\x12\x0e\n\x06rating\x18\t \x01(\x01\x12\x0c\n\x04\x64\x65sc\x18\n \x01(\t\x12>\n\tbadges_v2\x18\x0b \x03(\x0b\x32+.bilibili.polymer.app.search.v1.ReasonStyle\x12\x11\n\tstyles_v2\x18\x0c \x01(\t\"\xd4\x03\n\x13SearchOgvInlineCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x03 \x01(\t\x12\x0f\n\x07\x64\x61nmaku\x18\x04 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x05 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x06 \x01(\t\x12\x13\n\x0binline_type\x18\x07 \x01(\t\x12\x0b\n\x03mid\x18\x08 \x01(\x03\x12\x0c\n\x04play\x18\t \x01(\x03\x12\x44\n\nogv_inline\x18\n \x01(\x0b\x32\x30.bilibili.polymer.app.search.v1.SearchInlineData\x12\x42\n\rogv_clip_info\x18\x0b \x01(\x0b\x32+.bilibili.polymer.app.search.v1.OgvClipInfo\x12\x41\n\x0cwatch_button\x18\x0c \x01(\x0b\x32+.bilibili.polymer.app.search.v1.WatchButton\x12\r\n\x05score\x18\r \x01(\t\x12\x16\n\x0eogv_inline_exp\x18\x0e \x01(\x05\x12>\n\tbadges_v2\x18\x0f \x03(\x0b\x32+.bilibili.polymer.app.search.v1.ReasonStyle\"\x91\x01\n\x16SearchOgvRecommendCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12?\n\x05items\x18\x03 \x03(\x0b\x32\x30.bilibili.polymer.app.search.v1.OgvRecommendWord\x12\x18\n\x10special_bg_color\x18\x04 \x01(\t\"\x8e\x02\n\x15SearchOgvRelationCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x18\n\x10special_bg_color\x18\x03 \x01(\t\x12\x11\n\tmore_text\x18\x04 \x01(\t\x12\x10\n\x08more_url\x18\x05 \x01(\t\x12\x42\n\x05items\x18\x06 \x03(\x0b\x32\x33.bilibili.polymer.app.search.v1.DetailsRelationItem\x12\x14\n\x0cis_new_style\x18\x07 \x01(\x05\x12>\n\x0bogv_card_ui\x18\x08 \x01(\x0b\x32).bilibili.polymer.app.search.v1.OgvCardUI\"\xf8\x03\n\x15SearchOlympicGameCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12J\n\x11sports_match_item\x18\x03 \x01(\x0b\x32/.bilibili.polymer.app.search.v1.SportsMatchItem\x12<\n\tmatch_top\x18\x04 \x01(\x0b\x32).bilibili.polymer.app.search.v1.MatchItem\x12\x10\n\x08\x62g_cover\x18\x05 \x01(\t\x12=\n\nextra_link\x18\x06 \x03(\x0b\x32).bilibili.polymer.app.search.v1.ExtraLink\x12\x13\n\x0binline_type\x18\x07 \x01(\t\x12\x44\n\nugc_inline\x18\x08 \x01(\x0b\x32\x30.bilibili.polymer.app.search.v1.SearchInlineData\x12J\n\x10live_room_inline\x18\t \x01(\x0b\x32\x30.bilibili.polymer.app.search.v1.SearchInlineData\x12?\n\x0cmatch_bottom\x18\n \x01(\x0b\x32).bilibili.polymer.app.search.v1.MatchItem\"\xf2\x03\n\x15SearchOlympicWikiCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12N\n\x13\x63\x61rd_business_badge\x18\x03 \x01(\x0b\x32\x31.bilibili.polymer.app.search.v1.CardBusinessBadge\x12\x43\n\tread_more\x18\x04 \x01(\x0b\x32\x30.bilibili.polymer.app.search.v1.NavigationButton\x12\x13\n\x0binline_type\x18\x05 \x01(\t\x12\x44\n\nugc_inline\x18\x06 \x01(\x0b\x32\x30.bilibili.polymer.app.search.v1.SearchInlineData\x12J\n\x10live_room_inline\x18\x07 \x01(\x0b\x32\x30.bilibili.polymer.app.search.v1.SearchInlineData\x12?\n\x0bpedia_cover\x18\x08 \x01(\x0b\x32*.bilibili.polymer.app.search.v1.PediaCover\x12>\n\nnavigation\x18\t \x03(\x0b\x32*.bilibili.polymer.app.search.v1.Navigation\"\xe6\x02\n\x0fSearchPediaCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12>\n\nnavigation\x18\x03 \x03(\x0b\x32*.bilibili.polymer.app.search.v1.Navigation\x12\x43\n\tread_more\x18\x04 \x01(\x0b\x32\x30.bilibili.polymer.app.search.v1.NavigationButton\x12\x1f\n\x17navigation_module_count\x18\x05 \x01(\x05\x12?\n\x0bpedia_cover\x18\x06 \x01(\x0b\x32*.bilibili.polymer.app.search.v1.PediaCover\x12N\n\x13\x63\x61rd_business_badge\x18\x07 \x01(\x0b\x32\x31.bilibili.polymer.app.search.v1.CardBusinessBadge\"\xe4\x01\n\x12SearchPurchaseCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\r\n\x05\x62\x61\x64ge\x18\x03 \x01(\t\x12\r\n\x05venue\x18\x04 \x01(\t\x12\r\n\x05price\x18\x05 \x01(\x05\x12\x16\n\x0eprice_complete\x18\x06 \x01(\t\x12\x12\n\nprice_type\x18\x07 \x01(\x05\x12\x17\n\x0frequired_number\x18\x08 \x01(\x05\x12\x0c\n\x04\x63ity\x18\t \x01(\t\x12\x11\n\tshow_time\x18\n \x01(\t\x12\n\n\x02id\x18\x0b \x01(\x03\x12\x11\n\tshop_name\x18\x0c \x01(\t\"6\n\x16SearchRecommendTipCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\"t\n\x17SearchRecommendWordCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12;\n\x04list\x18\x03 \x03(\x0b\x32-.bilibili.polymer.app.search.v1.RecommendWord\"\xa7\x02\n\x11SearchSpecialCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x41\n\x0cnew_rec_tags\x18\x03 \x03(\x0b\x32+.bilibili.polymer.app.search.v1.ReasonStyle\x12N\n\x13\x63\x61rd_business_badge\x18\x04 \x01(\x0b\x32\x31.bilibili.polymer.app.search.v1.CardBusinessBadge\x12\r\n\x05\x62\x61\x64ge\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x06 \x01(\t\x12\x44\n\x0fnew_rec_tags_v2\x18\x07 \x03(\x0b\x32+.bilibili.polymer.app.search.v1.ReasonStyle\"S\n\x16SearchSpecialGuideCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\r\n\x05phone\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\"\xc8\x02\n\x0fSearchSportCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x10\n\x08\x62g_cover\x18\x03 \x01(\t\x12<\n\tmatch_top\x18\x04 \x01(\x0b\x32).bilibili.polymer.app.search.v1.MatchItem\x12?\n\x0cmatch_bottom\x18\x05 \x01(\x0b\x32).bilibili.polymer.app.search.v1.MatchItem\x12=\n\nextra_link\x18\x06 \x03(\x0b\x32).bilibili.polymer.app.search.v1.ExtraLink\x12;\n\x05items\x18\x07 \x03(\x0b\x32,.bilibili.polymer.app.search.v1.MatchInfoObj\x12\n\n\x02id\x18\x08 \x01(\x03\"\xad\x03\n\x15SearchSportInlineCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x10\n\x08\x62g_cover\x18\x03 \x01(\t\x12<\n\tmatch_top\x18\x04 \x01(\x0b\x32).bilibili.polymer.app.search.v1.MatchItem\x12?\n\x0cmatch_bottom\x18\x05 \x01(\x0b\x32).bilibili.polymer.app.search.v1.MatchItem\x12=\n\nextra_link\x18\x06 \x03(\x0b\x32).bilibili.polymer.app.search.v1.ExtraLink\x12;\n\x05items\x18\x07 \x03(\x0b\x32,.bilibili.polymer.app.search.v1.MatchInfoObj\x12\n\n\x02id\x18\x08 \x01(\x03\x12H\n\x0e\x65sports_inline\x18\t \x01(\x0b\x32\x30.bilibili.polymer.app.search.v1.SearchInlineData\x12\x13\n\x0binline_type\x18\n \x01(\t\"W\n\x0eSearchTipsCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x11\n\tsub_title\x18\x04 \x01(\t\x12\x14\n\x0b\x63over_night\x18\x86\x01 \x01(\t\"\xbf\x04\n\x11SearchTopGameCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\r\n\x05\x61rray\x18\x03 \x01(\x05\x12\x18\n\x10\x62\x61\x63kground_image\x18\x04 \x01(\t\x12\x13\n\x0b\x62utton_type\x18\x05 \x01(\x05\x12\x11\n\tgame_icon\x18\x06 \x01(\t\x12\x14\n\x0cgame_base_id\x18\x07 \x01(\x03\x12\x13\n\x0bgame_status\x18\x08 \x01(\x05\x12\x13\n\x0binline_type\x18\t \x01(\t\x12>\n\x0btop_game_ui\x18\n \x01(\x0b\x32).bilibili.polymer.app.search.v1.TopGameUI\x12\x16\n\x0enotice_content\x18\x0b \x01(\t\x12\x13\n\x0bnotice_name\x18\x0c \x01(\t\x12\x0e\n\x06rating\x18\r \x01(\x02\x12\r\n\x05score\x18\x0e \x01(\t\x12\x39\n\x08tab_info\x18\x0f \x03(\x0b\x32\'.bilibili.polymer.app.search.v1.TabInfo\x12\x0c\n\x04tags\x18\x10 \x01(\t\x12\x44\n\nugc_inline\x18\x11 \x01(\x0b\x32\x30.bilibili.polymer.app.search.v1.SearchInlineData\x12\x19\n\x11video_cover_image\x18\x12 \x01(\t\x12\x45\n\x0binline_live\x18\x13 \x01(\x0b\x32\x30.bilibili.polymer.app.search.v1.SearchInlineData\"\x9b\x02\n\x13SearchUgcInlineCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x03 \x01(\t\x12\x0f\n\x07\x64\x61nmaku\x18\x04 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x05 \x01(\t\x12\x13\n\x0binline_type\x18\x06 \x01(\t\x12\x0b\n\x03mid\x18\x07 \x01(\x03\x12\x0c\n\x04play\x18\x08 \x01(\x03\x12\x44\n\nugc_inline\x18\t \x01(\x0b\x32\x30.bilibili.polymer.app.search.v1.SearchInlineData\x12\x41\n\tfull_text\x18\n \x01(\x0b\x32..bilibili.polymer.app.search.v1.FullTextResult\"\xe8\x04\n\x0fSearchUpperCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0c\n\x04sign\x18\x03 \x01(\t\x12\x0c\n\x04\x66\x61ns\x18\x04 \x01(\x05\x12\x10\n\x08\x61rchives\x18\x05 \x01(\x05\x12\x13\n\x0blive_status\x18\x06 \x01(\x05\x12\x0e\n\x06roomid\x18\x07 \x01(\x05\x12G\n\x0fofficial_verify\x18\x08 \x01(\x0b\x32..bilibili.polymer.app.search.v1.OfficialVerify\x12\x14\n\x0c\x66\x61\x63\x65_nft_new\x18\t \x01(\x05\x12\x42\n\rnft_face_icon\x18\n \x01(\x0b\x32+.bilibili.polymer.app.search.v1.NftFaceIcon\x12\x38\n\x08\x61v_items\x18\x0b \x03(\x0b\x32&.bilibili.polymer.app.search.v1.AvItem\x12\r\n\x05is_up\x18\x0c \x01(\x08\x12\x12\n\nattentions\x18\r \x01(\x05\x12\r\n\x05level\x18\x0e \x01(\x05\x12\x18\n\x10is_senior_member\x18\x0f \x01(\x05\x12\x34\n\x03vip\x18\x10 \x01(\x0b\x32\'.bilibili.polymer.app.search.v1.VipInfo\x12:\n\x08relation\x18\x11 \x01(\x0b\x32(.bilibili.polymer.app.search.v1.Relation\x12\x11\n\tlive_link\x18\x12 \x01(\t\x12\x36\n\x06notice\x18\x13 \x01(\x0b\x32&.bilibili.polymer.app.search.v1.Notice\"\x8e\x06\n\x0fSearchVideoCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12?\n\x0brcmd_reason\x18\x03 \x01(\x0b\x32*.bilibili.polymer.app.search.v1.RcmdReason\x12\x41\n\x0cnew_rec_tags\x18\x04 \x03(\x0b\x32+.bilibili.polymer.app.search.v1.ReasonStyle\x12?\n\x0bthree_point\x18\x05 \x03(\x0b\x32*.bilibili.polymer.app.search.v1.ThreePoint\x12\x34\n\x05share\x18\x06 \x01(\x0b\x32%.bilibili.polymer.app.search.v1.Share\x12N\n\x13\x63\x61rd_business_badge\x18\x07 \x01(\x0b\x32\x31.bilibili.polymer.app.search.v1.CardBusinessBadge\x12\x0c\n\x04play\x18\x08 \x01(\x05\x12\x0f\n\x07\x64\x61nmaku\x18\t \x01(\x05\x12\x0e\n\x06\x61uthor\x18\n \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x0b \x01(\t\x12\x10\n\x08\x64uration\x18\x0c \x01(\t\x12;\n\x06\x62\x61\x64ges\x18\r \x03(\x0b\x32+.bilibili.polymer.app.search.v1.ReasonStyle\x12\x0b\n\x03mid\x18\x0e \x01(\x03\x12\x17\n\x0fshow_card_desc1\x18\x0f \x01(\t\x12\x17\n\x0fshow_card_desc2\x18\x10 \x01(\t\x12\x41\n\tfull_text\x18\x11 \x01(\x0b\x32..bilibili.polymer.app.search.v1.FullTextResult\x12\x44\n\x0fnew_rec_tags_v2\x18\x12 \x03(\x0b\x32+.bilibili.polymer.app.search.v1.ReasonStyle\x12>\n\tbadges_v2\x18\x13 \x03(\x0b\x32+.bilibili.polymer.app.search.v1.ReasonStyle\"K\n\x05Share\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x34\n\x05video\x18\x02 \x01(\x0b\x32%.bilibili.polymer.app.search.v1.Video\"a\n\x0fShareButtonItem\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12@\n\x0c\x62utton_metas\x18\x02 \x03(\x0b\x32*.bilibili.polymer.app.search.v1.ButtonMeta\"\x85\x03\n\nSharePlane\x12\r\n\x05title\x18\x01 \x01(\t\x12\x16\n\x0eshare_subtitle\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\r\n\x05\x63over\x18\x04 \x01(\t\x12\x0b\n\x03\x61id\x18\x05 \x01(\x03\x12\x0c\n\x04\x62vid\x18\x06 \x01(\t\x12\x39\n\x08share_to\x18\x07 \x01(\x0b\x32\'.bilibili.polymer.app.search.v1.ShareTo\x12\x0e\n\x06\x61uthor\x18\x08 \x01(\t\x12\x11\n\tauthor_id\x18\t \x01(\x03\x12\x12\n\nshort_link\x18\n \x01(\t\x12\x13\n\x0bplay_number\x18\x0b \x01(\t\x12\x0f\n\x07room_id\x18\x0c \x01(\x03\x12\r\n\x05\x65p_id\x18\r \x01(\x05\x12\x11\n\tarea_name\x18\x0e \x01(\t\x12\x13\n\x0b\x61uthor_face\x18\x0f \x01(\t\x12\x11\n\tseason_id\x18\x10 \x01(\x05\x12\x12\n\nshare_from\x18\x11 \x01(\t\x12\x14\n\x0cseason_title\x18\x12 \x01(\t\x12\x0c\n\x04\x66rom\x18\x13 \x01(\t\"\xeb\x01\n\x07ShareTo\x12\x0f\n\x07\x64ynamic\x18\x01 \x01(\x08\x12\n\n\x02im\x18\x02 \x01(\x08\x12\x0c\n\x04\x63opy\x18\x03 \x01(\x08\x12\x0c\n\x04more\x18\x04 \x01(\x08\x12\x0e\n\x06wechat\x18\x05 \x01(\x08\x12\r\n\x05weibo\x18\x06 \x01(\x08\x12\x16\n\x0ewechat_monment\x18\x07 \x01(\x08\x12\n\n\x02qq\x18\x08 \x01(\x08\x12\r\n\x05qzone\x18\t \x01(\x08\x12\x10\n\x08\x66\x61\x63\x65\x62ook\x18\n \x01(\x08\x12\x0c\n\x04line\x18\x0b \x01(\x08\x12\x11\n\tmessenger\x18\x0c \x01(\x08\x12\x11\n\twhats_app\x18\r \x01(\x08\x12\x0f\n\x07twitter\x18\x0e \x01(\x08\"d\n\x05Space\x12\x0c\n\x04show\x18\x01 \x01(\x05\x12\x12\n\ntext_color\x18\x02 \x01(\t\x12\x18\n\x10text_color_night\x18\x03 \x01(\t\x12\x0c\n\x04text\x18\x04 \x01(\t\x12\x11\n\tspace_url\x18\x05 \x01(\t\"\xb8\x01\n\x0fSportsMatchItem\x12\x10\n\x08match_id\x18\x01 \x01(\x03\x12\x11\n\tseason_id\x18\x02 \x01(\x03\x12\x12\n\nmatch_name\x18\x03 \x01(\t\x12\x0b\n\x03img\x18\x04 \x01(\t\x12\x17\n\x0f\x62\x65gin_time_desc\x18\x05 \x01(\t\x12\x19\n\x11match_status_desc\x18\x06 \x01(\t\x12\x13\n\x0bsub_content\x18\x07 \x01(\t\x12\x16\n\x0esub_extra_icon\x18\x08 \x01(\t\"1\n\x04Stat\x12\x0c\n\x04play\x18\x01 \x01(\x05\x12\x0c\n\x04like\x18\x02 \x01(\x05\x12\r\n\x05reply\x18\x03 \x01(\x05\":\n\x07TabInfo\x12\x10\n\x08tab_name\x18\x01 \x01(\t\x12\x0f\n\x07tab_url\x18\x02 \x01(\t\x12\x0c\n\x04sort\x18\x03 \x01(\x05\"\'\n\nTextButton\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"&\n\tTextLabel\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"5\n\x05Texts\x12\x14\n\x0c\x62ooking_text\x18\x01 \x01(\t\x12\x16\n\x0eunbooking_text\x18\x02 \x01(\t\"7\n\nThreePoint\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0c\n\x04icon\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xac\x01\n\x0bThreePoint2\x12\x46\n\x0f\x64islike_reasons\x18\x01 \x03(\x0b\x32-.bilibili.polymer.app.search.v1.DislikeReason\x12@\n\tfeedbacks\x18\x02 \x03(\x0b\x32-.bilibili.polymer.app.search.v1.DislikeReason\x12\x13\n\x0bwatch_later\x18\x03 \x01(\x05\"\x89\x01\n\x0cThreePointV2\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08subtitle\x18\x02 \x01(\t\x12>\n\x07reasons\x18\x03 \x03(\x0b\x32-.bilibili.polymer.app.search.v1.DislikeReason\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\x03\"\xf9\x01\n\x0cThreePointV3\x12\r\n\x05title\x18\x01 \x01(\t\x12\x16\n\x0eselected_title\x18\x02 \x01(\t\x12\x10\n\x08subtitle\x18\x03 \x01(\t\x12>\n\x07reasons\x18\x04 \x03(\x0b\x32-.bilibili.polymer.app.search.v1.DislikeReason\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\x03\x12\x10\n\x08selected\x18\x07 \x01(\x05\x12\x0c\n\x04icon\x18\x08 \x01(\t\x12\x15\n\rselected_icon\x18\t \x01(\t\x12\x0b\n\x03url\x18\n \x01(\t\x12\x12\n\ndefault_id\x18\x0b \x01(\x05\"\x90\x01\n\x0cThreePointV4\x12?\n\x0bshare_plane\x18\x01 \x01(\x0b\x32*.bilibili.polymer.app.search.v1.SharePlane\x12?\n\x0bwatch_later\x18\x02 \x01(\x0b\x32*.bilibili.polymer.app.search.v1.WatchLater\"\xa5\x01\n\tTopGameUI\x12\x18\n\x10\x62\x61\x63kground_image\x18\x01 \x01(\t\x12\x1b\n\x13\x63over_default_color\x18\x02 \x01(\t\x12\x1b\n\x13gaussian_blur_value\x18\x03 \x01(\t\x12\x18\n\x10mask_color_value\x18\x04 \x01(\t\x12\x14\n\x0cmask_opacity\x18\x05 \x01(\t\x12\x14\n\x0cmodule_color\x18\x06 \x01(\t\"\x7f\n\rTrafficConfig\x12\r\n\x05title\x18\x01 \x01(\t\x12\x44\n\x07options\x18\x02 \x03(\x0b\x32\x33.bilibili.polymer.app.search.v1.TrafficConfigOption\x12\x19\n\x11\x64\x65\x66\x61ult_option_id\x18\x03 \x01(\x03\"/\n\x13TrafficConfigOption\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04text\x18\x02 \x01(\t\"K\n\x06UpArgs\x12\r\n\x05up_id\x18\x01 \x01(\x03\x12\x0f\n\x07up_name\x18\x02 \x01(\t\x12\x0f\n\x07up_face\x18\x03 \x01(\t\x12\x10\n\x08selected\x18\x04 \x01(\x05\"F\n\x05Upper\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\x12\n\nptime_text\x18\x04 \x01(\t\"\x86\x01\n\x05Video\x12\x0c\n\x04\x62vid\x18\x01 \x01(\t\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\x12\x16\n\x0eshare_subtitle\x18\x03 \x01(\t\x12\x14\n\x0cis_hot_label\x18\x04 \x01(\x08\x12\x0c\n\x04page\x18\x05 \x01(\x05\x12\x12\n\npage_count\x18\x06 \x01(\x05\x12\x12\n\nshort_link\x18\x07 \x01(\t\"\xaa\x02\n\x07VipInfo\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12\x10\n\x08\x64ue_date\x18\x03 \x01(\x03\x12\x14\n\x0cvip_pay_type\x18\x04 \x01(\x05\x12\x12\n\ntheme_type\x18\x05 \x01(\x05\x12\x37\n\x05label\x18\x06 \x01(\x0b\x32(.bilibili.polymer.app.search.v1.VipLabel\x12\x18\n\x10\x61vatar_subscript\x18\x07 \x01(\x05\x12\x16\n\x0enickname_color\x18\x08 \x01(\t\x12\x0c\n\x04role\x18\t \x01(\x03\x12\x1c\n\x14\x61vatar_subscript_url\x18\n \x01(\t\x12\x15\n\rtv_vip_status\x18\x0b \x01(\x05\x12\x17\n\x0ftv_vip_pay_type\x18\x0c \x01(\x05\"\x9e\x02\n\x08VipLabel\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x13\n\x0blabel_theme\x18\x03 \x01(\t\x12\x12\n\ntext_color\x18\x04 \x01(\t\x12\x10\n\x08\x62g_style\x18\x05 \x01(\x05\x12\x10\n\x08\x62g_color\x18\x06 \x01(\t\x12\x14\n\x0c\x62order_color\x18\x07 \x01(\t\x12\x15\n\ruse_img_label\x18\x08 \x01(\x08\x12\x1a\n\x12img_label_uri_hans\x18\t \x01(\t\x12\x1a\n\x12img_label_uri_hant\x18\n \x01(\t\x12!\n\x19img_label_uri_hans_static\x18\x0b \x01(\t\x12!\n\x19img_label_uri_hant_static\x18\x0c \x01(\t\"*\n\x0bWatchButton\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04link\x18\x02 \x01(\t\"\x89\x01\n\x0bWatchedShow\x12\x0e\n\x06switch\x18\x01 \x01(\x08\x12\x0b\n\x03num\x18\x02 \x01(\x03\x12\x12\n\ntext_small\x18\x03 \x01(\t\x12\x12\n\ntext_large\x18\x04 \x01(\t\x12\x0c\n\x04icon\x18\x05 \x01(\t\x12\x15\n\ricon_location\x18\x06 \x01(\t\x12\x10\n\x08icon_web\x18\x07 \x01(\t\"\'\n\nWatchLater\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0c\n\x04\x62vid\x18\x02 \x01(\t*\xa7\x01\n\x0c\x43\x61tegorySort\x12\x19\n\x15\x43\x41TEGORY_SORT_DEFAULT\x10\x00\x12\x1e\n\x1a\x43\x41TEGORY_SORT_PUBLISH_TIME\x10\x01\x12\x1d\n\x19\x43\x41TEGORY_SORT_CLICK_COUNT\x10\x02\x12\x1f\n\x1b\x43\x41TEGORY_SORT_COMMENT_COUNT\x10\x03\x12\x1c\n\x18\x43\x41TEGORY_SORT_LIKE_COUNT\x10\x04*\\\n\x04Sort\x12\x10\n\x0cSORT_DEFAULT\x10\x00\x12\x13\n\x0fSORT_VIEW_COUNT\x10\x01\x12\x15\n\x11SORT_PUBLISH_TIME\x10\x02\x12\x16\n\x12SORT_DANMAKU_COUNT\x10\x03*\x91\x01\n\x08UserSort\x12\x15\n\x11USER_SORT_DEFAULT\x10\x00\x12\x1a\n\x16USER_SORT_FANS_DESCEND\x10\x01\x12\x19\n\x15USER_SORT_FANS_ASCEND\x10\x02\x12\x1b\n\x17USER_SORT_LEVEL_DESCEND\x10\x03\x12\x1a\n\x16USER_SORT_LEVEL_ASCEND\x10\x04*D\n\x08UserType\x12\x07\n\x03\x41LL\x10\x00\x12\x06\n\x02UP\x10\x01\x12\x0f\n\x0bNORMAL_USER\x10\x02\x12\x16\n\x12\x41UTHENTICATED_USER\x10\x03\x32\xed\x02\n\x06Search\x12p\n\tSearchAll\x12\x30.bilibili.polymer.app.search.v1.SearchAllRequest\x1a\x31.bilibili.polymer.app.search.v1.SearchAllResponse\x12y\n\x0cSearchByType\x12\x33.bilibili.polymer.app.search.v1.SearchByTypeRequest\x1a\x34.bilibili.polymer.app.search.v1.SearchByTypeResponse\x12v\n\x0bSearchComic\x12\x32.bilibili.polymer.app.search.v1.SearchComicRequest\x1a\x33.bilibili.polymer.app.search.v1.SearchComicResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.polymer.app.search.v1.search_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FOLLOWBUTTON_TEXTSENTRY._options = None
  _FOLLOWBUTTON_TEXTSENTRY._serialized_options = b'8\001'
  _SEARCHALLRESPONSE_ANNOTATIONENTRY._options = None
  _SEARCHALLRESPONSE_ANNOTATIONENTRY._serialized_options = b'8\001'
  _SEARCHBYTYPERESPONSE_ANNOTATIONENTRY._options = None
  _SEARCHBYTYPERESPONSE_ANNOTATIONENTRY._serialized_options = b'8\001'
  _globals['_CATEGORYSORT']._serialized_start=13320
  _globals['_CATEGORYSORT']._serialized_end=13487
  _globals['_SORT']._serialized_start=28785
  _globals['_SORT']._serialized_end=28877
  _globals['_USERSORT']._serialized_start=13560
  _globals['_USERSORT']._serialized_end=13705
  _globals['_USERTYPE']._serialized_start=13489
  _globals['_USERTYPE']._serialized_end=13557
  _globals['_ARGS']._serialized_start=168
  _globals['_ARGS']._serialized_end=308
  _globals['_AVATAR']._serialized_start=311
  _globals['_AVATAR']._serialized_end=499
  _globals['_AVITEM']._serialized_start=502
  _globals['_AVITEM']._serialized_end=709
  _globals['_BACKGROUND']._serialized_start=711
  _globals['_BACKGROUND']._serialized_end=777
  _globals['_BADGE']._serialized_start=779
  _globals['_BADGE']._serialized_end=818
  _globals['_BADGE2']._serialized_start=820
  _globals['_BADGE2']._serialized_end=860
  _globals['_BOTTOMBUTTON']._serialized_start=862
  _globals['_BOTTOMBUTTON']._serialized_end=904
  _globals['_BRANDADACCOUNT']._serialized_start=907
  _globals['_BRANDADACCOUNT']._serialized_end=1285
  _globals['_BRANDADARC']._serialized_start=1288
  _globals['_BRANDADARC']._serialized_end=1448
  _globals['_BUTTON']._serialized_start=1451
  _globals['_BUTTON']._serialized_end=1626
  _globals['_BUTTONMETA']._serialized_start=1628
  _globals['_BUTTONMETA']._serialized_end=1706
  _globals['_CARDBUSINESSBADGE']._serialized_start=1709
  _globals['_CARDBUSINESSBADGE']._serialized_end=1855
  _globals['_CHANNELLABEL']._serialized_start=1857
  _globals['_CHANNELLABEL']._serialized_end=1898
  _globals['_CHANNELMIXEDITEM']._serialized_start=1901
  _globals['_CHANNELMIXEDITEM']._serialized_end=2110
  _globals['_CHECKMORE']._serialized_start=2112
  _globals['_CHECKMORE']._serialized_end=2153
  _globals['_CLOUDGAMEPARAMS']._serialized_start=2155
  _globals['_CLOUDGAMEPARAMS']._serialized_end=2208
  _globals['_DETAILSRELATIONITEM']._serialized_start=2211
  _globals['_DETAILSRELATIONITEM']._serialized_end=2542
  _globals['_DISLIKEREASON']._serialized_start=2544
  _globals['_DISLIKEREASON']._serialized_end=2585
  _globals['_DISPLAYOPTION']._serialized_start=2587
  _globals['_DISPLAYOPTION']._serialized_end=2660
  _globals['_DYTOPIC']._serialized_start=2662
  _globals['_DYTOPIC']._serialized_end=2699
  _globals['_EASTEREGG']._serialized_start=2702
  _globals['_EASTEREGG']._serialized_end=2938
  _globals['_EPISODE']._serialized_start=2941
  _globals['_EPISODE']._serialized_end=3072
  _globals['_EPISODENEW']._serialized_start=3075
  _globals['_EPISODENEW']._serialized_end=3269
  _globals['_EXTRALINK']._serialized_start=3271
  _globals['_EXTRALINK']._serialized_end=3309
  _globals['_FOLLOWBUTTON']._serialized_start=3312
  _globals['_FOLLOWBUTTON']._serialized_end=3481
  _globals['_FOLLOWBUTTON_TEXTSENTRY']._serialized_start=3437
  _globals['_FOLLOWBUTTON_TEXTSENTRY']._serialized_end=3481
  _globals['_FULLTEXTRESULT']._serialized_start=3483
  _globals['_FULLTEXTRESULT']._serialized_end=3579
  _globals['_GOTOICON']._serialized_start=3581
  _globals['_GOTOICON']._serialized_end=3674
  _globals['_INLINEPROGRESSBAR']._serialized_start=3676
  _globals['_INLINEPROGRESSBAR']._serialized_end=3781
  _globals['_INLINETHREEPOINTPANEL']._serialized_start=3784
  _globals['_INLINETHREEPOINTPANEL']._serialized_end=3944
  _globals['_ITEM']._serialized_start=3947
  _globals['_ITEM']._serialized_end=6475
  _globals['_LIKERESOURCE']._serialized_start=6477
  _globals['_LIKERESOURCE']._serialized_end=6526
  _globals['_LIVEBADGERESOURCE']._serialized_start=6529
  _globals['_LIVEBADGERESOURCE']._serialized_end=6739
  _globals['_MASK']._serialized_start=6741
  _globals['_MASK']._serialized_end=6859
  _globals['_MATCHINFOOBJ']._serialized_start=6862
  _globals['_MATCHINFOOBJ']._serialized_end=7233
  _globals['_MATCHITEM']._serialized_start=7236
  _globals['_MATCHITEM']._serialized_end=7408
  _globals['_MATCHTEAM']._serialized_start=7410
  _globals['_MATCHTEAM']._serialized_end=7478
  _globals['_NAV']._serialized_start=7480
  _globals['_NAV']._serialized_end=7543
  _globals['_NAVIGATION']._serialized_start=7546
  _globals['_NAVIGATION']._serialized_end=7795
  _globals['_NAVIGATIONBUTTON']._serialized_start=7797
  _globals['_NAVIGATIONBUTTON']._serialized_end=7856
  _globals['_NFTFACEICON']._serialized_start=7858
  _globals['_NFTFACEICON']._serialized_end=7927
  _globals['_NOTICE']._serialized_start=7930
  _globals['_NOTICE']._serialized_end=8143
  _globals['_OFFICIALVERIFY']._serialized_start=8145
  _globals['_OFFICIALVERIFY']._serialized_end=8189
  _globals['_OGVCARDUI']._serialized_start=8191
  _globals['_OGVCARDUI']._serialized_end=8279
  _globals['_OGVCLIPINFO']._serialized_start=8281
  _globals['_OGVCLIPINFO']._serialized_end=8342
  _globals['_OGVRECOMMENDWORD']._serialized_start=8344
  _globals['_OGVRECOMMENDWORD']._serialized_end=8419
  _globals['_PEDIACOVER']._serialized_start=8421
  _globals['_PEDIACOVER']._serialized_end=8544
  _globals['_PLAYERARGS']._serialized_start=8547
  _globals['_PLAYERARGS']._serialized_end=8885
  _globals['_PLAYERWIDGET']._serialized_start=8887
  _globals['_PLAYERWIDGET']._serialized_end=8930
  _globals['_RANKINFO']._serialized_start=8933
  _globals['_RANKINFO']._serialized_end=9170
  _globals['_RCMDREASON']._serialized_start=9172
  _globals['_RCMDREASON']._serialized_end=9201
  _globals['_REASONSTYLE']._serialized_start=9204
  _globals['_REASONSTYLE']._serialized_end=9387
  _globals['_RECOMMENDWORD']._serialized_start=9389
  _globals['_RECOMMENDWORD']._serialized_end=9469
  _globals['_RELATION']._serialized_start=9471
  _globals['_RELATION']._serialized_end=9497
  _globals['_RIGHTTOPLIVEBADGE']._serialized_start=9500
  _globals['_RIGHTTOPLIVEBADGE']._serialized_end=9633
  _globals['_SEARCHADCARD']._serialized_start=9635
  _globals['_SEARCHADCARD']._serialized_end=9667
  _globals['_SEARCHALLREQUEST']._serialized_start=9670
  _globals['_SEARCHALLREQUEST']._serialized_end=9984
  _globals['_SEARCHALLRESPONSE']._serialized_start=9987
  _globals['_SEARCHALLRESPONSE']._serialized_end=10595
  _globals['_SEARCHALLRESPONSE_ANNOTATIONENTRY']._serialized_start=10546
  _globals['_SEARCHALLRESPONSE_ANNOTATIONENTRY']._serialized_end=10595
  _globals['_SEARCHARTICLECARD']._serialized_start=10598
  _globals['_SEARCHARTICLECARD']._serialized_end=10814
  _globals['_SEARCHAUTHORNEWCARD']._serialized_start=10817
  _globals['_SEARCHAUTHORNEWCARD']._serialized_end=11849
  _globals['_SEARCHBANGUMICARD']._serialized_start=11852
  _globals['_SEARCHBANGUMICARD']._serialized_end=12818
  _globals['_SEARCHBANNERCARD']._serialized_start=12820
  _globals['_SEARCHBANNERCARD']._serialized_end=12868
  _globals['_SEARCHBYTYPEREQUEST']._serialized_start=12871
  _globals['_SEARCHBYTYPEREQUEST']._serialized_end=13705
  _globals['_SEARCHBYTYPEREQUEST_CATEGORYSORT']._serialized_start=13320
  _globals['_SEARCHBYTYPEREQUEST_CATEGORYSORT']._serialized_end=13487
  _globals['_SEARCHBYTYPEREQUEST_USERTYPE']._serialized_start=13489
  _globals['_SEARCHBYTYPEREQUEST_USERTYPE']._serialized_end=13557
  _globals['_SEARCHBYTYPEREQUEST_USERSORT']._serialized_start=13560
  _globals['_SEARCHBYTYPEREQUEST_USERSORT']._serialized_end=13705
  _globals['_SEARCHBYTYPERESPONSE']._serialized_start=13708
  _globals['_SEARCHBYTYPERESPONSE']._serialized_end=14077
  _globals['_SEARCHBYTYPERESPONSE_ANNOTATIONENTRY']._serialized_start=10546
  _globals['_SEARCHBYTYPERESPONSE_ANNOTATIONENTRY']._serialized_end=10595
  _globals['_SEARCHCOLLECTIONCARD']._serialized_start=14080
  _globals['_SEARCHCOLLECTIONCARD']._serialized_end=14350
  _globals['_SEARCHCOMICCARD']._serialized_start=14352
  _globals['_SEARCHCOMICCARD']._serialized_end=14462
  _globals['_SEARCHCOMICINFO']._serialized_start=14464
  _globals['_SEARCHCOMICINFO']._serialized_end=14573
  _globals['_SEARCHCOMICREQUEST']._serialized_start=14575
  _globals['_SEARCHCOMICREQUEST']._serialized_end=14612
  _globals['_SEARCHCOMICRESPONSE']._serialized_start=14614
  _globals['_SEARCHCOMICRESPONSE']._serialized_end=14699
  _globals['_SEARCHDYNAMICCARD']._serialized_start=14702
  _globals['_SEARCHDYNAMICCARD']._serialized_end=14953
  _globals['_SEARCHGAMECARD']._serialized_start=14956
  _globals['_SEARCHGAMECARD']._serialized_end=15352
  _globals['_SEARCHINLINEDATA']._serialized_start=15355
  _globals['_SEARCHINLINEDATA']._serialized_end=16959
  _globals['_SEARCHLIKEBUTTONITEM']._serialized_start=16962
  _globals['_SEARCHLIKEBUTTONITEM']._serialized_end=17344
  _globals['_SEARCHLIVECARD']._serialized_start=17347
  _globals['_SEARCHLIVECARD']._serialized_end=17676
  _globals['_SEARCHLIVEINLINECARD']._serialized_start=17679
  _globals['_SEARCHLIVEINLINECARD']._serialized_end=17948
  _globals['_SEARCHNEWCHANNELCARD']._serialized_start=17951
  _globals['_SEARCHNEWCHANNELCARD']._serialized_end=18330
  _globals['_SEARCHNORESULTSUGGESTWORDCARD']._serialized_start=18332
  _globals['_SEARCHNORESULTSUGGESTWORDCARD']._serialized_end=18420
  _globals['_SEARCHOGVCARD']._serialized_start=18423
  _globals['_SEARCHOGVCARD']._serialized_end=18571
  _globals['_SEARCHOGVCHANNELCARD']._serialized_start=18574
  _globals['_SEARCHOGVCHANNELCARD']._serialized_end=18884
  _globals['_SEARCHOGVINLINECARD']._serialized_start=18887
  _globals['_SEARCHOGVINLINECARD']._serialized_end=19355
  _globals['_SEARCHOGVRECOMMENDCARD']._serialized_start=19358
  _globals['_SEARCHOGVRECOMMENDCARD']._serialized_end=19503
  _globals['_SEARCHOGVRELATIONCARD']._serialized_start=19506
  _globals['_SEARCHOGVRELATIONCARD']._serialized_end=19776
  _globals['_SEARCHOLYMPICGAMECARD']._serialized_start=19779
  _globals['_SEARCHOLYMPICGAMECARD']._serialized_end=20283
  _globals['_SEARCHOLYMPICWIKICARD']._serialized_start=20286
  _globals['_SEARCHOLYMPICWIKICARD']._serialized_end=20784
  _globals['_SEARCHPEDIACARD']._serialized_start=20787
  _globals['_SEARCHPEDIACARD']._serialized_end=21145
  _globals['_SEARCHPURCHASECARD']._serialized_start=21148
  _globals['_SEARCHPURCHASECARD']._serialized_end=21376
  _globals['_SEARCHRECOMMENDTIPCARD']._serialized_start=21378
  _globals['_SEARCHRECOMMENDTIPCARD']._serialized_end=21432
  _globals['_SEARCHRECOMMENDWORDCARD']._serialized_start=21434
  _globals['_SEARCHRECOMMENDWORDCARD']._serialized_end=21550
  _globals['_SEARCHSPECIALCARD']._serialized_start=21553
  _globals['_SEARCHSPECIALCARD']._serialized_end=21848
  _globals['_SEARCHSPECIALGUIDECARD']._serialized_start=21850
  _globals['_SEARCHSPECIALGUIDECARD']._serialized_end=21933
  _globals['_SEARCHSPORTCARD']._serialized_start=21936
  _globals['_SEARCHSPORTCARD']._serialized_end=22264
  _globals['_SEARCHSPORTINLINECARD']._serialized_start=22267
  _globals['_SEARCHSPORTINLINECARD']._serialized_end=22696
  _globals['_SEARCHTIPSCARD']._serialized_start=22698
  _globals['_SEARCHTIPSCARD']._serialized_end=22785
  _globals['_SEARCHTOPGAMECARD']._serialized_start=22788
  _globals['_SEARCHTOPGAMECARD']._serialized_end=23363
  _globals['_SEARCHUGCINLINECARD']._serialized_start=23366
  _globals['_SEARCHUGCINLINECARD']._serialized_end=23649
  _globals['_SEARCHUPPERCARD']._serialized_start=23652
  _globals['_SEARCHUPPERCARD']._serialized_end=24268
  _globals['_SEARCHVIDEOCARD']._serialized_start=24271
  _globals['_SEARCHVIDEOCARD']._serialized_end=25053
  _globals['_SHARE']._serialized_start=25055
  _globals['_SHARE']._serialized_end=25130
  _globals['_SHAREBUTTONITEM']._serialized_start=25132
  _globals['_SHAREBUTTONITEM']._serialized_end=25229
  _globals['_SHAREPLANE']._serialized_start=25232
  _globals['_SHAREPLANE']._serialized_end=25621
  _globals['_SHARETO']._serialized_start=25624
  _globals['_SHARETO']._serialized_end=25859
  _globals['_SPACE']._serialized_start=25861
  _globals['_SPACE']._serialized_end=25961
  _globals['_SPORTSMATCHITEM']._serialized_start=25964
  _globals['_SPORTSMATCHITEM']._serialized_end=26148
  _globals['_STAT']._serialized_start=26150
  _globals['_STAT']._serialized_end=26199
  _globals['_TABINFO']._serialized_start=26201
  _globals['_TABINFO']._serialized_end=26259
  _globals['_TEXTBUTTON']._serialized_start=26261
  _globals['_TEXTBUTTON']._serialized_end=26300
  _globals['_TEXTLABEL']._serialized_start=26302
  _globals['_TEXTLABEL']._serialized_end=26340
  _globals['_TEXTS']._serialized_start=26342
  _globals['_TEXTS']._serialized_end=26395
  _globals['_THREEPOINT']._serialized_start=26397
  _globals['_THREEPOINT']._serialized_end=26452
  _globals['_THREEPOINT2']._serialized_start=26455
  _globals['_THREEPOINT2']._serialized_end=26627
  _globals['_THREEPOINTV2']._serialized_start=26630
  _globals['_THREEPOINTV2']._serialized_end=26767
  _globals['_THREEPOINTV3']._serialized_start=26770
  _globals['_THREEPOINTV3']._serialized_end=27019
  _globals['_THREEPOINTV4']._serialized_start=27022
  _globals['_THREEPOINTV4']._serialized_end=27166
  _globals['_TOPGAMEUI']._serialized_start=27169
  _globals['_TOPGAMEUI']._serialized_end=27334
  _globals['_TRAFFICCONFIG']._serialized_start=27336
  _globals['_TRAFFICCONFIG']._serialized_end=27463
  _globals['_TRAFFICCONFIGOPTION']._serialized_start=27465
  _globals['_TRAFFICCONFIGOPTION']._serialized_end=27512
  _globals['_UPARGS']._serialized_start=27514
  _globals['_UPARGS']._serialized_end=27589
  _globals['_UPPER']._serialized_start=27591
  _globals['_UPPER']._serialized_end=27661
  _globals['_VIDEO']._serialized_start=27664
  _globals['_VIDEO']._serialized_end=27798
  _globals['_VIPINFO']._serialized_start=27801
  _globals['_VIPINFO']._serialized_end=28099
  _globals['_VIPLABEL']._serialized_start=28102
  _globals['_VIPLABEL']._serialized_end=28388
  _globals['_WATCHBUTTON']._serialized_start=28390
  _globals['_WATCHBUTTON']._serialized_end=28432
  _globals['_WATCHEDSHOW']._serialized_start=28435
  _globals['_WATCHEDSHOW']._serialized_end=28572
  _globals['_WATCHLATER']._serialized_start=28574
  _globals['_WATCHLATER']._serialized_end=28613
  _globals['_SEARCH']._serialized_start=29098
  _globals['_SEARCH']._serialized_end=29463
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.broadcast.v1 import broadcast_pb2 as bilibili_dot_broadcast_dot_v1_dot_broadcast__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class BroadcastStub(object):
    """broadcast操作，对应每个target_path
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Auth = channel.unary_unary(
                '/bilibili.broadcast.v1.Broadcast/Auth',
                request_serializer=bilibili_dot_broadcast_dot_v1_dot_broadcast__pb2.AuthReq.SerializeToString,
                response_deserializer=bilibili_dot_broadcast_dot_v1_dot_broadcast__pb2.AuthResp.FromString,
                )
        self.Heartbeat = channel.unary_unary(
                '/bilibili.broadcast.v1.Broadcast/Heartbeat',
                request_serializer=bilibili_dot_broadcast_dot_v1_dot_broadcast__pb2.HeartbeatReq.SerializeToString,
                response_deserializer=bilibili_dot_broadcast_dot_v1_dot_broadcast__pb2.HeartbeatResp.FromString,
                )
        self.Subscribe = channel.unary_unary(
                '/bilibili.broadcast.v1.Broadcast/Subscribe',
                request_serializer=bilibili_dot_broadcast_dot_v1_dot_broadcast__pb2.TargetPath.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.Unsubscribe = channel.unary_unary(
                '/bilibili.broadcast.v1.Broadcast/Unsubscribe',
                request_serializer=bilibili_dot_broadcast_dot_v1_dot_broadcast__pb2.TargetPath.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.MessageAck = channel.unary_unary(
                '/bilibili.broadcast.v1.Broadcast/MessageAck',
                request_serializer=bilibili_dot_broadcast_dot_v1_dot_broadcast__pb2.MessageAckReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class BroadcastServicer(object):
    """broadcast操作，对应每个target_path
    """

    def Auth(self, request, context):
        """用户鉴权
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Heartbeat(self, request, context):
        """心跳保活：成功心跳为4分45秒，重试心跳为30s，三次收不到进行重连（不超过5分45）
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Subscribe(self, request, context):
        """订阅target_path
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Unsubscribe(self, request, context):
        """取消订阅target_path
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MessageAck(self, request, context):
        """消息回执
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BroadcastServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Auth': grpc.unary_unary_rpc_method_handler(
                    servicer.Auth,
                    request_deserializer=bilibili_dot_broadcast_dot_v1_dot_broadcast__pb2.AuthReq.FromString,
                    response_serializer=bilibili_dot_broadcast_dot_v1_dot_broadcast__pb2.AuthResp.SerializeToString,
            ),
            'Heartbeat': grpc.unary_unary_rpc_method_handler(
                    servicer.Heartbeat,
                    request_deserializer=bilibili_dot_broadcast_dot_v1_dot_broadcast__pb2.HeartbeatReq.FromString,
                    response_serializer=bilibili_dot_broadcast_dot_v1_dot_broadcast__pb2.HeartbeatResp.SerializeToString,
            ),
            'Subscribe': grpc.unary_unary_rpc_method_handler(
                    servicer.Subscribe,
                    request_deserializer=bilibili_dot_broadcast_dot_v1_dot_broadcast__pb2.TargetPath.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'Unsubscribe': grpc.unary_unary_rpc_method_handler(
                    servicer.Unsubscribe,
                    request_deserializer=bilibili_dot_broadcast_dot_v1_dot_broadcast__pb2.TargetPath.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'MessageAck': grpc.unary_unary_rpc_method_handler(
                    servicer.MessageAck,
                    request_deserializer=bilibili_dot_broadcast_dot_v1_dot_broadcast__pb2.MessageAckReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.broadcast.v1.Broadcast', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Broadcast(object):
    """broadcast操作，对应每个target_path
    """

    @staticmethod
    def Auth(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.broadcast.v1.Broadcast/Auth',
            bilibili_dot_broadcast_dot_v1_dot_broadcast__pb2.AuthReq.SerializeToString,
            bilibili_dot_broadcast_dot_v1_dot_broadcast__pb2.AuthResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Heartbeat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.broadcast.v1.Broadcast/Heartbeat',
            bilibili_dot_broadcast_dot_v1_dot_broadcast__pb2.HeartbeatReq.SerializeToString,
            bilibili_dot_broadcast_dot_v1_dot_broadcast__pb2.HeartbeatResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Subscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.broadcast.v1.Broadcast/Subscribe',
            bilibili_dot_broadcast_dot_v1_dot_broadcast__pb2.TargetPath.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Unsubscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.broadcast.v1.Broadcast/Unsubscribe',
            bilibili_dot_broadcast_dot_v1_dot_broadcast__pb2.TargetPath.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MessageAck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.broadcast.v1.Broadcast/MessageAck',
            bilibili_dot_broadcast_dot_v1_dot_broadcast__pb2.MessageAckReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class BroadcastTunnelStub(object):
    """broadcast连接隧道
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateTunnel = channel.stream_stream(
                '/bilibili.broadcast.v1.BroadcastTunnel/CreateTunnel',
                request_serializer=bilibili_dot_broadcast_dot_v1_dot_broadcast__pb2.BroadcastFrame.SerializeToString,
                response_deserializer=bilibili_dot_broadcast_dot_v1_dot_broadcast__pb2.BroadcastFrame.FromString,
                )


class BroadcastTunnelServicer(object):
    """broadcast连接隧道
    """

    def CreateTunnel(self, request_iterator, context):
        """创建双向stream连接隧道
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BroadcastTunnelServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateTunnel': grpc.stream_stream_rpc_method_handler(
                    servicer.CreateTunnel,
                    request_deserializer=bilibili_dot_broadcast_dot_v1_dot_broadcast__pb2.BroadcastFrame.FromString,
                    response_serializer=bilibili_dot_broadcast_dot_v1_dot_broadcast__pb2.BroadcastFrame.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.broadcast.v1.BroadcastTunnel', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class BroadcastTunnel(object):
    """broadcast连接隧道
    """

    @staticmethod
    def CreateTunnel(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/bilibili.broadcast.v1.BroadcastTunnel/CreateTunnel',
            bilibili_dot_broadcast_dot_v1_dot_broadcast__pb2.BroadcastFrame.SerializeToString,
            bilibili_dot_broadcast_dot_v1_dot_broadcast__pb2.BroadcastFrame.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
